#
# spec file for package tovid
#
# Copyright (c) 2015-2022 Luigi Baldoni <aloisio@gmx.com>
# Copyright (c) 2005-2010 oc2pus
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.links2linux.org/
#


Name:           tovid
Version:        0.35.2
Release:        1699.3.pm.7
Summary:        Video conversion and DVD authoring tools
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Video/Editors and Convertors
URL:            http://tovid.wikia.com/wiki/Tovid_Wiki
Source:         https://github.com/tovid-suite/tovid/releases/download/%{version}/tovid-%{version}.tar.gz
BuildRequires:  hicolor-icon-theme
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  txt2tags
BuildRequires:  update-desktop-files
Requires:       /usr/bin/mkisofs
Requires:       ImageMagick >= 6.0
Requires:       MPlayer
Requires:       bc
Requires:       binutils
Requires:       dvd+rw-tools
Requires:       dvdauthor >= 0.6.0
Requires:       ffmpeg
Requires:       lsdvd
Requires:       mjpegtools
Requires:       normalize
Requires:       python3-base >= %{py3_ver}
Requires:       python3-tk
Requires:       sox
Requires:       tix
Requires:       tk
Recommends:     libdvdcss2
Recommends:     transcode
BuildArch:      noarch

%description
tovid is a suite of utilities designed to make DVD
authoring a little less painful. tovid can create MPEG output
from arbitrary video formats, help you identify video files,
generate graphical menus for DVD (animated or static),
generate DVD directories with the appropriate file structure,
and optionally burn them to disk.

%prep
%setup -q
# fix shebang
sed -i 's|^#!.*|#!/bin/bash|'   \
 src/idvid src/makedvd src/makempg    \
 src/todisc src/todisc-fade-routine   \
 src/tovid-init.in
sed -i 's|^#!.*|#!%{_bindir}/python3|' \
 src/set_chapters src/titleset-wizard \
 src/todiscgui src/tovid-stats

%build
python3 setup.py build

%install
python3 setup.py install \
    --prefix=%{_prefix} \
    --root=%{buildroot}

rm -f "%{buildroot}%{_prefix}/lib/tovid/.install.log"
chmod +x %{buildroot}%{_prefix}/lib/tovid/set_chapters
chmod +x %{buildroot}%{_prefix}/lib/tovid/tovid-init

for x in tovidgui titleset-wizard; do
    %suse_update_desktop_file -r "$x" AudioVideo AudioVideoEditing
done

%files
%license COPYING
%doc AUTHORS ChangeLog README
%{_bindir}/tovid
%{python3_sitelib}/libtovid
%{python3_sitelib}/tovid-%{version}*
%{_prefix}/lib/tovid
%{_datadir}/applications/tovidgui.desktop
%{_datadir}/applications/titleset-wizard.desktop
%{_datadir}/icons/*/*/apps/tovid.png
%{_datadir}/icons/*/*/apps/titleset-wizard.png
%{_datadir}/icons/*/scalable/apps/*.svg
%{_mandir}/man1/tovid.1%{?ext_man}

%changelog
* Sun Jun 12 2022 Luigi Baldoni <aloisio@gmx.com>
- Force python3 build
* Mon Jul 15 2019 Dave Plater <davejplater@gmail.com>
- Fix incorrect requirement for nonexistant /usr/bin/bash
* Fri May 24 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.35.2
  * Fixed set_chapters not having exec bit set
  * Fixed grep for libav filters
  * Some python3 fixes
  * Fixed scope problem that only showed up on freebsd for some
    reason.
  * Fixed imagemagick spumux buttons for IM-6.9.1-x.
  * Make ffmpeg the default encoder when both ffmpeg and avconv
    are present.
* Mon Apr  6 2015 aloisio@gmx.com
- Version 0.35.0
  * minor changes
  * moved project to github
- Dropped tovid-rpmlintrc
* Sat Mar 14 2015 aloisio@gmx.com
- Update to 0.35
  * full changelog at http://tovid.wikia.com/wiki/Tovid_changelog
- Fixed build for 13.2 and newer
* Fri Dec 26 2014 obs@botter.cc
- Require /usr/bin/mkisofs instead of just mkisofs [PM-118]
* Wed Nov 13 2013 obs@botter.cc
- Buildrequire cdrkit-cdrtools-compat instead of mkisofs for > 1230
* Wed Jul 27 2011 pascal.bleser@opensuse.org
- update to 0.34:
  * a new GUI for making multiple titlesets with tovid
  * includes many updates and fixes for changes in the backends like ffmpeg and
    dvdauthor as well as numerous bugfixes
  * new libavfilter features from ffmpeg have been implemented, so the
  - quick-menu option now works again with a recent enough libavfilter and
    ffmpeg (0.8)
  * several new options have also been added, including the ability to use your
    own arbitrary images for thumbnail links
  * PNG is now used generally as an intermediary format instead of JPEG,
    resulting in improved picture quality
* Sun Apr  3 2011 pascal.bleser@opensuse.org
- add Requires:binutils to fix runtime, thanks to Jeremy Dipietro for reporting
* Wed Jul 28 2010 toni@links2linux.de
- update to 0.33
- This release switches to a distutils-based installation using setup.py,
  adds a new tovid.ini configuration file, and makes various bugfixes and
  improvements.
* Fri Apr 30 2010 toni@links2linux.de
- update to 0.32
- This is the first tovid release in well over two years. It brings numerous GUI
  and command-line changes, bugfixes, and other improvements. The command-line
  scripts, manpages, and GUI have been unified into a single script called
  "tovid".
* Sun Mar  8 2009 toni@links2linux.de
- added a patch for todisc from Dmitri <dimig2mail@gmail.com> THX!
* Thu Feb  5 2009 toni@links2linux.de
- update to 0.40 (r2777)
* Sat Oct  6 2007 toni@links2linux.de
- rebuild with svn snapshot, to allow also wxPython 2.8
* Mon Aug 20 2007 toni@links2linux.de
- update to 0.31
* Sat Jul  7 2007 toni@links2linux.de
- patched for new ffmpeg
* Mon Feb 12 2007 toni@links2linux.de
- update to 0.30
* Mon Nov  6 2006 toni@links2linux.de
- update to 0.29
- changed BuildArch
* Sun Sep 17 2006 toni@links2linux.de
- build for packman
* Thu Jul 13 2006 oc2pus@arcor.de 0.28-0.oc2pus.1
- update to 0.28
- removed package tovid-gui
* Sat Jun  3 2006 oc2pus@arcor.de 0.27-0.oc2pus.1
- update to 0.27
* Tue Apr  4 2006 oc2pus@arcor.de 0.26-0.oc2pus.1
- update to 0.26
* Thu Mar  2 2006 oc2pus@arcor.de 0.25-0.oc2pus.2
- patched tovidgui.py
* Mon Feb 13 2006 oc2pus@arcor.de 0.25-0.oc2pus.1
- update to 0.25
* Wed Dec 21 2005 oc2pus@arcor.de 0.24-0.oc2pus.1
- rejoined package tovid and tovid-gui
* Wed Dec  7 2005 oc2pus@arcor.de 0.23-0.oc2pus.2
- included patch
* Tue Nov 15 2005 oc2pus@arcor.de 0.23-0.oc2pus.1
- update to 0.23
* Sun Sep 18 2005 oc2pus@arcor.de 0.22-0.oc2pus.1
- update to 0.22
* Sun Aug 28 2005 oc2pus@arcor.de 0.21-0.oc2pus.1
- update to 0.21
* Tue Aug 16 2005 oc2pus@arcor.de 0.20-0.oc2pus.1
- update to 0.20
* Thu Jul 28 2005 oc2pus@arcor.de 0.19-0.oc2pus.1
- update to 0.19
- repacked as tar.bz2
- switch to automake/autoconf/configure
* Wed Jul  6 2005 oc2pus@arcor.de 0.18-0.oc2pus.1
- update to 0.18
- split in 2 packages
* Wed Mar  2 2005 oc2pus@arcor.de 0.18b-0.oc2pus.1
- update to 0.18b
* Thu Feb 10 2005 oc2pus@arcor.de 0.18a-0.oc2pus.1
- update to 0.18a
* Tue Nov 23 2004 oc2pus@arcor.de 0.16-0.oc2pus.1
- update to 0.16
* Tue Nov 16 2004 oc2pus@arcor.de 0.15-0.oc2pus.1
- update to 0.15
- no gui packaged, deprecated
* Thu Nov  4 2004 oc2pus@arcor.de 0.14-0.oc2pus.1
- initial build for apt-repository
- added documentation from homepage
